==> bigloo2.6b.tar.gz: bigloo2.6b/runtime/Llib/make-lib.scm <==
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/runtime/Llib/make-lib.scm            */
;*    -------------------------------------------------------------    */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Sun Jan  8 10:11:38 1995                          */
;*    Last change :  Thu Apr  3 06:08:34 2003 (serrano)                */
;*    -------------------------------------------------------------    */
;*    The construction of the library                                  */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    The module                                                       */
;*---------------------------------------------------------------------*/
(module __make-lib
   
   (import  __type
	    __bigloo
	    __error
	    __os
	    __bexit
	    __structure
	    __hash
	    __tvector
	    __bit
	    __binary
	    __intext
	    __foreign
	    __object
	    __dsssl
	    __ucs2
	    __unicode
	    __process
	    __socket
	    __pregexp
	    __date

	    __reader

	    __pp
	    __pp_circle

	    __rgc
	    __rgc_expand

	    __macro
            __eval
            __evenv
	    (evmeaning-location        __evmeaning)
	    (evmeaning-notify-error    __evmeaning)
            __expand
	    (register-eval-srfi!       __expander_srfi-0)
	    (args-parse-usage          __expander_args)

	    __match_expand
	    (match-define-structure!   __match_normalize)

	    __r4_booleans_6_1
	    __r4_equivalence_6_2
	    __r4_pairs_and_lists_6_3
	    __r4_symbols_6_4
	    __r4_numbers_6_5
	    __r4_numbers_6_5_fixnum
	    __r4_numbers_6_5_flonum
	    __r4_characters_6_6
	    __r4_strings_6_7
	    __r4_vectors_6_8
	    __r4_control_features_6_9
	    __r4_ports_6_10_1
	    __r4_input_6_10_2
	    __r4_output_6_10_3
	    
	    __r5_control_features_6_4
	    __r5_macro_4_3_hygiene
	    
	    __lalr_driver
	    __lalr_expand))

==> bigloo_2.7a-1.tar.gz: bigloo2.7a/runtime/Llib/make-lib.scm <==
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/runtime/Llib/make-lib.scm            */
;*    -------------------------------------------------------------    */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Sun Jan  8 10:11:38 1995                          */
;*    Last change :  Sun Jul 10 11:22:41 2005 (serrano)                */
;*    -------------------------------------------------------------    */
;*    The construction of the library                                  */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    The module                                                       */
;*---------------------------------------------------------------------*/
(module __make-lib
   
   (import  __param
	    __type
	    __bigloo
	    __error
	    __os
	    __bexit
	    __structure
	    __hash
	    __tvector
	    __bit
	    __binary
	    __intext
	    __foreign
	    __object
	    __dsssl
	    __ucs2
	    __unicode
	    __process
	    __socket
	    __pregexp
	    __date
	    __thread
	    __mmap
	    __trace
	    __base64
	    __md5

	    __reader

	    __pp
	    __pp_circle

	    __rgc
	    __rgc_expand

	    __macro
            __eval
            __evenv
	    (evmeaning-location         __evmeaning)
	    (evmeaning-notify-error     __everror)
            __expand
	    (register-eval-srfi!        __expander_srfi-0)
	    (args-parse-usage           __expander_args)
	    __library

	    __match_expand
	    (match-define-structure!    __match_normalize)

	    __r4_booleans_6_1
	    __r4_equivalence_6_2
	    __r4_pairs_and_lists_6_3
	    __r4_symbols_6_4
	    __r4_numbers_6_5
	    __r4_numbers_6_5_fixnum
	    __r4_numbers_6_5_flonum
	    __r4_characters_6_6
	    __r4_strings_6_7
	    __r4_vectors_6_8
	    __r4_control_features_6_9
	    __r4_ports_6_10_1
	    __r4_input_6_10_2
	    __r4_output_6_10_3
	    
	    __r5_control_features_6_4
	    __r5_macro_4_3_hygiene
	    
	    __lalr_driver
	    __lalr_expand))
